==> moodle-1.5-mysql.tgz: moodle/lang/nl/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005033100)


$string['addresource'] = 'Bron toevoegen';
$string['chooseafile'] = 'Kies of upload een bestand';
$string['chooseparameter'] = 'Kies parameter';
$string['configallowlocalfiles'] = 'Laat toe om bij het maken van een nieuwe bron links te maken naar een lokaal bestandssysteem zoals een CD-ROM station of een harde schijf. Dit kan nuttig zijn in klassituaties waar alle leerlingen toegang hebben tot gedeelde netwerkschijven of wanneer bestanden op een CD gebruikt moeten worden. Om deze functie te kunnen gebruiken kan het nodig zijn de beveiligingsinstellingen van de browser te wijzigen.';
$string['configdefaulturl'] = 'Deze waarde wordt gebruikt om een deel van de URL in te vullen wanneer er een nieuwe URL-gebaseerde bron gemaakt wordt.';
$string['configfilterexternalpages'] = 'Door deze instelling in te schakelen zullen alle externe bronnen (webpagina\'s, geploade HTML-pagina\'s) verwerkt worden door de sitefilters (zoals de autolinks van de woordenlijst bijvoorbeeld). Door deze optie in te schakelen kan je site behoorlijk vertragen - gebruik dit voorzichtig en alleen als je het echt nodig hebt';
$string['configframesize'] = 'Als een webpagina of een gepload bestand binnen een frame wordt weergegeven, dan is deze waarde de hoogte (in pixels) van het bovenste frame (dat de navigatie bevat).';
$string['configparametersettings'] = 'Dit stelt de standaardwaarden voor het \"Parameters\" instellingspaneel van het formulier voor het invoeren van nieuwe bronnen. De voorkeur van de individuele gebruiker wordt na een eerste toegang verder gebruikt. ';
$string['configpopup'] = 'Als een nieuwe bron toegevoegd wordt die in een popup-venster getoond kan worden, moet dat dan de standaardoptie zijn?';
$string['configpopupdirectories'] = 'Wil je dat in popup-vensters standaard de links naar mappen getoond worden?';
$string['configpopupheight'] = 'Welke hoogte is de standaardhoogte voor popup-vensters?';
$string['configpopuplocation'] = 'Wil je dat popup-vensters standaard een adresbalk hebben?';
$string['configpopupmenubar'] = 'Wil je dat popup-venster standaard een menubalk hebben?';
$string['configpopupresizable'] = 'Wil je dat de grootte van popup-vensters standaard kan gewijzigd worden?';
$string['configpopupscrollbars'] = 'Wil je dat scrollen in popup-vensters standaard mogelijk is?';
$string['configpopupstatus'] = 'Wil je dat popup-vensters standaard een statusbalk hebben?';
$string['configpopuptoolbar'] = 'Wil je dat popup-vensters standaard een knoppenbalk hebben?';
$string['configpopupwidth'] = 'Hoe breed zou een popup-venster standaard moeten zijn?';
$string['configsecretphrase'] = 'Deze geheime zin wordt gebruikt om de gencrypteerde code te genereren die naar sommige bronnen als een parameter kan meegestuurd worden. De gencrypteerde code wordt gemaakt met een md5-waarde van het IP-adress van de huidige gebruiker samen met je geheime zin. ie code = md5(IP.secretphrase). Dit laat de bron op de bestemming toe de connectie te controleren voor extra veiligheid.';
$string['configwebsearch'] = 'Wanneer je een URL als webpagina of link toevoegt, wordt deze plaats aangeboden als een site om de gebruiker te helpen de URL te zoeken.';
$string['configwindowsettings'] = 'Dit stelt de standaardwaarden voor het \"Venster\" instellingspaneel van het formulier voor het invoeren van nieuwe bronnen. De voorkeur van de individuele gebruiker wordt na een eerste toegang verder gebruikt.';
$string['directlink'] = 'Rechtstreekse link naar dit bestand';
$string['directoryinfo'] = 'Alle bestanden in de gekozen map zullen getoond worden.';
$string['display'] = 'Venster';
$string['editingaresource'] = 'Bewerk een bron';
$string['encryptedcode'] = 'Gencrypteerde code';
$string['example'] = 'Voorbeeld';
$string['exampleurl'] = 'http://www.voorbeeld.nl/eenmap/eenbestand.html';
$string['fetchclienterror'] = 'Er is een fout opgetreden bij je webclient toen je de webpagina probeerde te openen (waarschijnlijk een verkeerde URL).';
$string['fetcherror'] = 'Er is een fout gevonden tijdens het ophalen van de webpagina.';
$string['fetchservererror'] = 'Er is een fout gevonden bij de webserver terwijl je probeerde een webpagina op te halen (waarschijnlijk een programmafout).</p>';
$string['filename'] = 'Bestandsnaam';
$string['filtername'] = 'Automatisch linken van bronnen';
$string['frameifpossible'] = 'Toon de bron in een frame, zodat de navigatie zichtbaar blijft';
$string['fulltext'] = 'Volledige tekst';
$string['htmlfragment'] = 'HTML-fragment';
$string['localfile'] = 'Lokaal bestand';
$string['localfilechoose'] = 'Kies een lokaal bestand (CD-ROM)';
$string['localfilehelp'] = 'Help bij het tonen van lokale bestanden';
$string['localfileinfo'] = '<p>Kies een bestand van je computer. Het bestand zal  niet geploadet worden naar de website, maar Moodle zal hetzelfde bestand zoeken op de computer van iedereen die deze bron bekijkt.</p><p>Dit is vooral nuttig wanneer je grote bestanden op een standaard CD-ROM bewaart en die verdeelt onder je leerlingen. Elke leerling kan zijn eigen lokale pad kiezen voor zulke bestanden, door <a href=\"$a\" target=\"_blank\">zijn gebruikersprofiel te bewerken</a>.</p>';
$string['localfilepath'] = 'Om je eigen lokale pad voor deze bron in te stellen, kies je een bestand van de schijf (gewoonlijk CD-ROM-station) van je computer waard dit bestand staat. Het bestand zal niet geploadet worden, maar de bestandslocatie zal bewaard worden en gebruikt worden voor alle lokale bestanden.';
$string['localfileselect'] = 'Kies dit bestandspad';
$string['maindirectory'] = 'Hoofdmap';
$string['modulename'] = 'Bron';
$string['modulenameplural'] = 'Bronnen';
$string['neverseen'] = 'Nooit bekeken';
$string['newdirectories'] = 'Toon de links naar de mappen';
$string['newfullscreen'] = 'Vul het volledige scherm';
$string['newheight'] = 'Standaardvensterhoogte (in pixels)';
$string['newlocation'] = 'Toon de locatiebalk';
$string['newmenubar'] = 'Toon de menubalk';
$string['newresizable'] = 'Sta het veranderen van de grootte van het venster toe';
$string['newscrollbars'] = 'Sta scrollen van het venster toe';
$string['newstatus'] = 'Toon de statusbalk';
$string['newtoolbar'] = 'Toon de werkbalk';
$string['newwidth'] = 'Standaardvensterbreedte (in pixels)';
$string['newwindow'] = 'Nieuw venster';
$string['newwindowopen'] = 'Toon deze bron in een popup-venster';
$string['notallowedlocalfileaccess'] = 'Toegang tot lokale bestanden is op dit moment uitgeschakeld. Deze bron is dus niet beschikbaar.';
$string['note'] = 'Aantekening';
$string['notefile'] = 'Gebruik <a href=\"$a\">Bestandsbeheer</a> om meer bestanden naar de cursus te uploaden (zodat ze in deze lijst verschijnen).';
$string['notypechosen'] = 'Je moet een soort kiezen. Gebruik de \'Back\'-knop om terug te gaan en het opnieuw te proberen.';
$string['pagedisplay'] = 'Toon deze bron in het huidige venster';
$string['pagewindow'] = 'Zelfde venster';
$string['pan'] = 'Pan';
$string['parameter'] = 'Parameter';
$string['parameters'] = 'Parameters';
$string['popupresource'] = 'Deze bron zou moeten in een popup-venster verschijnen';
$string['popupresourcelink'] = 'Als ze dat niet deed, klik hier: $a';
$string['resourcetype'] = 'Soort bron';
$string['resourcetype1'] = 'Verwijzing';
$string['resourcetype2'] = 'Webpagina';
$string['resourcetype3'] = 'Geploaded bestand';
$string['resourcetype4'] = 'Platte tekst';
$string['resourcetype5'] = 'Web link';
$string['resourcetype6'] = 'HTML-tekst';
$string['resourcetype7'] = 'Programma';
$string['resourcetype8'] = 'Wiki-achtige tekst';
$string['resourcetype9'] = 'Map';
$string['resourcetypedirectory'] = 'Map tonen';
$string['resourcetypefile'] = 'Bestand/website linken';
$string['resourcetypehtml'] = 'Webpagina maken';
$string['resourcetypelabel'] = 'Label toevoegen';
$string['resourcetypetext'] = 'Tekstpagina maken';
$string['searchweb'] = 'Zoek webpagina\'s';
$string['serverurl'] = 'Server URL ($a->wwwroot)';
$string['variablename'] = 'Variable naam';
$string['vol'] = 'Vol';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/nl/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005033100)


$string['addresource'] = 'Bron toevoegen';
$string['chooseafile'] = 'Kies of upload een bestand';
$string['chooseparameter'] = 'Kies parameter';
$string['configallowlocalfiles'] = 'Laat toe om bij het maken van een nieuwe bron links te maken naar een lokaal bestandssysteem zoals een CD-ROM station of een harde schijf. Dit kan nuttig zijn in klassituaties waar alle leerlingen toegang hebben tot gedeelde netwerkschijven of wanneer bestanden op een CD gebruikt moeten worden. Om deze functie te kunnen gebruiken kan het nodig zijn de beveiligingsinstellingen van de browser te wijzigen.';
$string['configdefaulturl'] = 'Deze waarde wordt gebruikt om een deel van de URL in te vullen wanneer er een nieuwe URL-gebaseerde bron gemaakt wordt.';
$string['configfilterexternalpages'] = 'Door deze instelling in te schakelen zullen alle externe bronnen (webpagina\'s, geploade HTML-pagina\'s) verwerkt worden door de sitefilters (zoals de autolinks van de woordenlijst bijvoorbeeld). Door deze optie in te schakelen kan je site behoorlijk vertragen - gebruik dit voorzichtig en alleen als je het echt nodig hebt';
$string['configframesize'] = 'Als een webpagina of een gepload bestand binnen een frame wordt weergegeven, dan is deze waarde de hoogte (in pixels) van het bovenste frame (dat de navigatie bevat).';
$string['configparametersettings'] = 'Dit stelt de standaardwaarden voor het \"Parameters\" instellingspaneel van het formulier voor het invoeren van nieuwe bronnen. De voorkeur van de individuele gebruiker wordt na een eerste toegang verder gebruikt. ';
$string['configpopup'] = 'Als een nieuwe bron toegevoegd wordt die in een popup-venster getoond kan worden, moet dat dan de standaardoptie zijn?';
$string['configpopupdirectories'] = 'Wil je dat in popup-vensters standaard de links naar mappen getoond worden?';
$string['configpopupheight'] = 'Wat is de standaardhoogte voor popup-vensters?';
$string['configpopuplocation'] = 'Wil je dat popup-vensters standaard een adresbalk hebben?';
$string['configpopupmenubar'] = 'Wil je dat popup-venster standaard een menubalk hebben?';
$string['configpopupresizable'] = 'Wil je dat de grootte van popup-vensters standaard kan gewijzigd worden?';
$string['configpopupscrollbars'] = 'Wil je dat scrollen in popup-vensters standaard mogelijk is?';
$string['configpopupstatus'] = 'Wil je dat popup-vensters standaard een statusbalk hebben?';
$string['configpopuptoolbar'] = 'Wil je dat popup-vensters standaard een knoppenbalk hebben?';
$string['configpopupwidth'] = 'Hoe breed zou een popup-venster standaard moeten zijn?';
$string['configsecretphrase'] = 'Deze geheime zin wordt gebruikt om de gencrypteerde code te genereren die naar sommige bronnen als een parameter kan meegestuurd worden. De gencrypteerde code wordt gemaakt met een md5-waarde van het IP-adress van de huidige gebruiker samen met je geheime zin. ie code = md5(IP.secretphrase). Dit laat de bron op de bestemming toe de connectie te controleren voor extra veiligheid.';
$string['configwebsearch'] = 'Wanneer je een URL als webpagina of link toevoegt, wordt deze plaats aangeboden als een site om de gebruiker te helpen de URL te zoeken.';
$string['configwindowsettings'] = 'Dit stelt de standaardwaarden voor het \"Venster\" instellingspaneel van het formulier voor het invoeren van nieuwe bronnen. De voorkeur van de individuele gebruiker wordt na een eerste toegang verder gebruikt.';
$string['directlink'] = 'Rechtstreekse link naar dit bestand';
$string['directoryinfo'] = 'Alle bestanden in de gekozen map zullen getoond worden.';
$string['display'] = 'Venster';
$string['editingaresource'] = 'Bewerk een bron';
$string['encryptedcode'] = 'Gencrypteerde code';
$string['example'] = 'Voorbeeld';
$string['exampleurl'] = 'http://www.voorbeeld.nl/eenmap/eenbestand.html';
$string['fetchclienterror'] = 'Er is een fout opgetreden bij je webclient toen je de webpagina probeerde te openen (waarschijnlijk een verkeerde URL).';
$string['fetcherror'] = 'Er is een fout gevonden tijdens het ophalen van de webpagina.';
$string['fetchservererror'] = 'Er is een fout gevonden bij de webserver terwijl je probeerde een webpagina op te halen (waarschijnlijk een programmafout).</p>';
$string['filename'] = 'Bestandsnaam';
$string['filtername'] = 'Automatisch linken van bronnen';
$string['frameifpossible'] = 'Toon de bron in een frame, zodat de navigatie zichtbaar blijft';
$string['fulltext'] = 'Volledige tekst';
$string['htmlfragment'] = 'HTML-fragment';
$string['localfile'] = 'Lokaal bestand';
$string['localfilechoose'] = 'Kies een lokaal bestand (CD-ROM)';
$string['localfilehelp'] = 'Help bij het tonen van lokale bestanden';
$string['localfileinfo'] = '<p>Kies een bestand van je computer. Het bestand zal  niet geploadet worden naar de website, maar Moodle zal hetzelfde bestand zoeken op de computer van iedereen die deze bron bekijkt.</p><p>Dit is vooral nuttig wanneer je grote bestanden op een standaard CD-ROM bewaart en die verdeelt onder je leerlingen. Elke leerling kan zijn eigen lokale pad kiezen voor zulke bestanden, door <a href=\"$a\" target=\"_blank\">zijn gebruikersprofiel te bewerken</a>.</p>';
$string['localfilepath'] = 'Om je eigen lokale pad voor deze bron in te stellen, kies je een bestand van de schijf (gewoonlijk CD-ROM-station) van je computer waard dit bestand staat. Het bestand zal niet geploadet worden, maar de bestandslocatie zal bewaard worden en gebruikt worden voor alle lokale bestanden.';
$string['localfileselect'] = 'Kies dit bestandspad';
$string['maindirectory'] = 'Hoofdmap';
$string['modulename'] = 'Bron';
$string['modulenameplural'] = 'Bronnen';
$string['neverseen'] = 'Nooit bekeken';
$string['newdirectories'] = 'Toon de links naar de mappen';
$string['newfullscreen'] = 'Vul het volledige scherm';
$string['newheight'] = 'Standaardvensterhoogte (in pixels)';
$string['newlocation'] = 'Toon de locatiebalk';
$string['newmenubar'] = 'Toon de menubalk';
$string['newresizable'] = 'Sta het veranderen van de grootte van het venster toe';
$string['newscrollbars'] = 'Sta scrollen van het venster toe';
$string['newstatus'] = 'Toon de statusbalk';
$string['newtoolbar'] = 'Toon de werkbalk';
$string['newwidth'] = 'Standaardvensterbreedte (in pixels)';
$string['newwindow'] = 'Nieuw venster';
$string['newwindowopen'] = 'Toon deze bron in een popup-venster';
$string['notallowedlocalfileaccess'] = 'Toegang tot lokale bestanden is op dit moment uitgeschakeld. Deze bron is dus niet beschikbaar.';
$string['note'] = 'Aantekening';
$string['notefile'] = 'Gebruik <a href=\"$a\">Bestandsbeheer</a> om meer bestanden naar de cursus te uploaden (zodat ze in deze lijst verschijnen).';
$string['notypechosen'] = 'Je moet een soort kiezen. Gebruik de \'Back\'-knop om terug te gaan en het opnieuw te proberen.';
$string['pagedisplay'] = 'Toon deze bron in het huidige venster';
$string['pagewindow'] = 'Zelfde venster';
$string['pan'] = 'Pan';
$string['parameter'] = 'Parameter';
$string['parameters'] = 'Parameters';
$string['popupresource'] = 'Deze bron zou moeten in een popup-venster verschijnen';
$string['popupresourcelink'] = 'Als ze dat niet deed, klik hier: $a';
$string['resourcetype'] = 'Soort bron';
$string['resourcetype1'] = 'Verwijzing';
$string['resourcetype2'] = 'Webpagina';
$string['resourcetype3'] = 'Gepload bestand';
$string['resourcetype4'] = 'Platte tekst';
$string['resourcetype5'] = 'Weblink';
$string['resourcetype6'] = 'HTML-tekst';
$string['resourcetype7'] = 'Programma';
$string['resourcetype8'] = 'Wiki-achtige tekst';
$string['resourcetype9'] = 'Map';
$string['resourcetypedirectory'] = 'Map tonen';
$string['resourcetypefile'] = 'Bestand/website linken';
$string['resourcetypehtml'] = 'Webpagina maken';
$string['resourcetypelabel'] = 'Label toevoegen';
$string['resourcetypetext'] = 'Tekstpagina maken';
$string['searchweb'] = 'Zoek webpagina\'s';
$string['serverurl'] = 'Server URL ($a->wwwroot)';
$string['variablename'] = 'Variable naam';
$string['vol'] = 'Vol';

?>
